/* OGMRip - A library for DVD ripping and encoding
 * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMRIP_MP4_H__
#define __OGMRIP_MP4_H__

#include <ogmrip-container.h>

G_BEGIN_DECLS

#define OGMRIP_TYPE_MP4          (ogmrip_mp4_get_type ())
#define OGMRIP_MP4(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_MP4, OGMRipMp4))
#define OGMRIP_MP4_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_MP4, OGMRipMp4Class))
#define OGMRIP_IS_MP4(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_MP4))
#define OGMRIP_IS_MP4_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_MP4))

typedef struct _OGMRipMp4      OGMRipMp4;
typedef struct _OGMRipMp4Class OGMRipMp4Class;
typedef struct _OGMRipMp4Priv  OGMRipMp4Priv;

struct _OGMRipMp4
{
  OGMRipContainer parent_instance;

  OGMRipMp4Priv *priv;
};

struct _OGMRipMp4Class
{
  OGMRipContainerClass parent_class;
};

GType         ogmrip_mp4_get_type (void);
OGMJobSpawn * ogmrip_mp4_new      (const gchar *output);

G_END_DECLS

#endif /* __OGMRIP_MP4_H__ */

